BOOST_PP_SEQ_TO_ARRAY

The BOOST_PP_SEQ_TO_ARRAY macro converts a seq to an array.

#### Usage

BOOST_PP_SEQ_TO_ARRAY(seq)

#### Arguments

seq
  The seq to be converted.

#### Requirements

Header: <boost/preprocessor/seq/to_array.hpp>

#### Sample Code

    #include <boost/preprocessor/seq/to_array.hpp>

    #define SEQ (a)(b)(c)

    BOOST_PP_SEQ_TO_ARRAY(SEQ) // expands to (3, (a, b, c))

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)